@@ -191,7 +191,7 @@ async def streamerShareHandler(event: PrivateMessageEvent):
     roomNumber = data['meta']['news']['jumpUrl'].split('?')[0].split('/')[-1]
     
     try:
-        isUidSuccess, uid = GetUidByRoomNumber(roomNumber)
+        isUidSuccess, uid = await GetUidByRoomNumber(roomNumber)
     except Exception:
         ex_type, ex_val, _ = sys.exc_info()
         logger.error(f'{__PLUGIN_NAME}获取主播 <{uid}> 信息时发生错误')
@@ -247,7 +247,7 @@ async def b23UrlShareHandler(event: PrivateMessageEvent):
     userID = event.sender.user_id
     
     try:
-        isSuccess, idType, id = parseB23Url(b23Url)
+        isSuccess, idType, id = await parseB23Url(b23Url)
     except Exception:
         ex_type, ex_val, _ = sys.exc_info()
         logger.error(f'{__PLUGIN_NAME}解析短链接 <{b23Url}> 时发生错误')
@@ -257,7 +257,7 @@ async def b23UrlShareHandler(event: PrivateMessageEvent):
         if isSuccess:
             if idType == 1:
                 try:
-                    isUidSuccess, uid = GetUidByRoomNumber(id)
+                    isUidSuccess, uid = await GetUidByRoomNumber(id)
                 except Exception:
                     ex_type, ex_val, _ = sys.exc_info()
                     logger.error(f'{__PLUGIN_NAME}获取主播 <{uid}> 信息时发生错误')
@@ -292,7 +292,6 @@ async def b23UrlShareHandler(event: PrivateMessageEvent):
 helpCommand = on_command("help", permission=ALL_PERMISSION, aliases={'帮助'})
 @helpCommand.handle()
 async def sendHelpMsg(event: MessageEvent):
-    userID = event.sender.user_id
     helpMsg = ""
     with open(f'{PackagePath}/file/source/help.json', 'r', encoding='utf-8') as f:
         helpMsg = json.load(f)
@@ -319,7 +318,7 @@ async def sendBroacast(event: MessageEvent):
         await publicBroacast.finish("公告发送失败: 公告文件不存在") 
 
 scheduler = require("nonebot_plugin_apscheduler").scheduler
-scheduler.add_job(CheckBiliStream, "interval", seconds=10, id="biliStream", misfire_grace_time=90)
+scheduler.add_job(CheckBiliStream, "interval", minutes=1, id="biliStream", misfire_grace_time=90)
 scheduler.add_job(CheckUpUpdate, "interval", minutes=1, id="biliUp", misfire_grace_time=90)
 scheduler.add_job(CheckTeleUpdate, "interval", minutes=5, id="biliTele", misfire_grace_time=90)
 
